==> qip-catalog-library-0.1.7-sources.jar: org/qubership/integration/platform/catalog/persistence/configs/entity/chain/FoldableEntity.java <==
/*
 * Copyright 2024-2025 NetCracker Technology Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.qubership.integration.platform.catalog.persistence.configs.entity.chain;

import jakarta.persistence.FetchType;
import jakarta.persistence.JoinColumn;
import jakarta.persistence.ManyToOne;
import jakarta.persistence.MappedSuperclass;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;
import lombok.experimental.SuperBuilder;
import org.hibernate.annotations.OnDelete;
import org.hibernate.annotations.OnDeleteAction;
import org.qubership.integration.platform.catalog.persistence.configs.entity.AbstractEntity;

import java.util.LinkedHashMap;
import java.util.Map;

@Getter
@Setter
@SuperBuilder
@NoArgsConstructor
@MappedSuperclass
public class FoldableEntity extends AbstractEntity {

    @OnDelete(action = OnDeleteAction.CASCADE)
    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "parent_folder_id")
    protected Folder parentFolder;

    protected FoldableEntity(FoldableEntity entity) {
        super(entity);
        this.parentFolder = entity.parentFolder;
    }

    public Map<String, String> getAncestors() {
        Map<String, String> navigationMap = new LinkedHashMap<>();
        FoldableEntity foldable = this;
        while (foldable != null) {
            navigationMap.put(foldable.getId(), foldable.getName());
            foldable = foldable.getParentFolder();
        }
        return navigationMap;
    }
}

==> qip-catalog-library-2025.1.1.15-sources.jar: org/qubership/integration/platform/catalog/persistence/configs/entity/chain/FoldableEntity.java <==
/*
 * Copyright 2024-2025 NetCracker Technology Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.qubership.integration.platform.catalog.persistence.configs.entity.chain;

import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;
import lombok.experimental.SuperBuilder;
import org.hibernate.annotations.OnDelete;
import org.hibernate.annotations.OnDeleteAction;

import org.qubership.integration.platform.catalog.persistence.configs.entity.AbstractEntity;

import jakarta.persistence.*;
import java.util.LinkedHashMap;
import java.util.Map;

@Getter
@Setter
@SuperBuilder
@NoArgsConstructor
@MappedSuperclass
public class FoldableEntity extends AbstractEntity {

    @OnDelete(action = OnDeleteAction.CASCADE)
    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "parent_folder_id")
    protected Folder parentFolder;

    protected FoldableEntity(FoldableEntity entity) {
        super(entity);
        this.parentFolder = entity.parentFolder;
    }

    public Map<String, String> getAncestors() {
        Map<String, String> navigationMap = new LinkedHashMap<>();
        FoldableEntity foldable = this;
        while (foldable != null) {
            navigationMap.put(foldable.getId(), foldable.getName());
            foldable = foldable.getParentFolder();
        }
        return navigationMap;
    }
}
